@@ -1,8 +1,15 @@
+//! Debugging utilities.
+//!
+//! While these utilities are primarily designed to help aid with testing and debugging of exporters
+//! and core parts of the `metrics` ecosystem, they can be beneficial for in-process collecting of
+//! metrics in some limited cases.
+
 use core::hash::Hash;
 use std::sync::atomic::Ordering;
 use std::sync::{Arc, Mutex};
 use std::{collections::HashMap, fmt::Debug};
 
+use crate::registry::AtomicStorage;
 use crate::{kind::MetricKind, registry::Registry, CompositeKey};
 
 use indexmap::IndexMap;
@@ -20,9 +27,11 @@ impl CompositeKeyName {
     }
 }
 
+/// A point-in-time snapshot of all metrics in [`DebuggingRecorder`].
 pub struct Snapshot(Vec<(CompositeKey, Option<Unit>, Option<&'static str>, DebugValue)>);
 
 impl Snapshot {
+    /// Converts this snapshot to a mapping of metric data, keyed by the metric key itself.
     #[allow(clippy::mutable_key_type)]
     pub fn into_hashmap(
         self,
@@ -33,6 +42,7 @@ impl Snapshot {
             .collect::<HashMap<_, _>>()
     }
 
+    /// Converts this snapshot to a vector of metric data tuples.
     pub fn into_vec(self) -> Vec<(CompositeKey, Option<Unit>, Option<&'static str>, DebugValue)> {
         self.0
     }
@@ -49,9 +59,9 @@ pub enum DebugValue {
     Histogram(Vec<OrderedFloat<f64>>),
 }
 
-/// Captures point-in-time snapshots of `DebuggingRecorder`.
+/// Captures point-in-time snapshots of [`DebuggingRecorder`].
 pub struct Snapshotter {
-    registry: Arc<Registry>,
+    registry: Arc<Registry<Key, AtomicStorage>>,
     seen: Arc<Mutex<IndexMap<CompositeKey, ()>>>,
     metadata: Arc<Mutex<IndexMap<CompositeKeyName, (Option<Unit>, &'static str)>>>,
 }
@@ -107,7 +117,7 @@ impl Snapshotter {
 /// Callers can easily take snapshots of the metrics at any given time and get access
 /// to the raw values.
 pub struct DebuggingRecorder {
-    registry: Arc<Registry>,
+    registry: Arc<Registry<Key, AtomicStorage>>,
     seen: Arc<Mutex<IndexMap<CompositeKey, ()>>>,
     metadata: Arc<Mutex<IndexMap<CompositeKeyName, (Option<Unit>, &'static str)>>>,
 }
@@ -116,7 +126,7 @@ impl DebuggingRecorder {
     /// Creates a new `DebuggingRecorder`.
     pub fn new() -> DebuggingRecorder {
         DebuggingRecorder {
-            registry: Arc::new(Registry::new()),
+            registry: Arc::new(Registry::atomic()),
             seen: Arc::new(Mutex::new(IndexMap::new())),
             metadata: Arc::new(Mutex::new(IndexMap::new())),
         }
