@@ -8,9 +8,7 @@ mod bucket;
 pub use bucket::AtomicBucket;
 
 #[cfg(feature = "debugging")]
-mod debugging;
-#[cfg(feature = "debugging")]
-pub use debugging::{DebugValue, DebuggingRecorder, Snapshotter};
+pub mod debugging;
 
 #[cfg(feature = "handles")]
 mod handles;
@@ -19,9 +17,7 @@ mod quantile;
 pub use quantile::{parse_quantiles, Quantile};
 
 #[cfg(feature = "registry")]
-mod registry;
-#[cfg(feature = "registry")]
-pub use registry::{Registry, StandardPrimitives};
+pub mod registry;
 
 mod common;
 pub use common::*;
@@ -42,8 +38,5 @@ pub use summary::Summary;
 
 pub mod layers;
 
-#[cfg(feature = "recency")]
-pub mod recency;
-
 #[cfg(test)]
 mod test_util;
